# Do Not Translate [![Build Status](https://travis-ci.com/ChenghaoMou/elisa-dnt.svg?token=9nvvJ4htB9CrTskFFEhv&branch=master)](https://travis-ci.com/ChenghaoMou/elisa-dnt)

Find, remove and restore regex-matched language-independent tokens before and after translation.

## Usage

```shell
python -m elisa_dnt --help
```